pub async fn run_affected(
cwd: &Path,
target: &str,
base_branch: &str,
) -> Result<RunResult, AffectedError>Expand description
Run a target only on affected projects (changed + their dependents).
Detects which projects have changed since the base branch and runs the target on those projects plus any projects that transitively depend on them.